@@ -11,6 +11,7 @@ function(x) {
      if(x == "gld") return("Generalized Lambda")
      if(x == "glo") return("Generalized Logistic")
      if(x == "gno") return("Generalized Normal")
+     if(x == "gov") return("Govindarajulu")
      if(x == "gpa") return("Generalized Pareto")
      if(x == "gum") return("Gumbel")
      if(x == "kap") return("Kappa")
@@ -20,6 +21,8 @@ function(x) {
      if(x == "ln3") return("log-Normal3")
      if(x == "nor") return("Normal")
      if(x == "pe3") return("Pearson Type III")
+     if(x == "sla") return("Slash")
+     if(x == "st3") return("Student t (3-parameter")
      if(x == "ray") return("Rayleigh")
      if(x == "rice") return("Rice")
      if(x == "revgum") return("Reverse Gumbel")
